┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinmainwindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphinmainwindow.h')
-rw-r--r--src/dolphinmainwindow.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/dolphinmainwindow.h b/src/dolphinmainwindow.h
index d72c6b938..f87e70dc4 100644
--- a/src/dolphinmainwindow.h
+++ b/src/dolphinmainwindow.h
@@ -401,11 +401,10 @@ private slots:
void slotTabMoved(int from, int to);
/**
* Is connected to the searchbox signal 'textChanged' and
* takes care to make the search options configurator visible
* if a search text has been entered.
*/
- void slotSearchBoxTextChanged(const QString& text);
+ void showSearchOptions();
private:
DolphinMainWindow(int id);
@@ -401,11 +401,10 @@ private slots:
void slotTabMoved(int from, int to);
/**
- * Is connected to the searchbox signal 'textChanged' and
- * takes care to make the search options configurator visible
- * if a search text has been entered.
+ * Is connected to the searchbox signal 'requestSearchOptions' and
+ * takes care to show the search options.
*/